"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("@code-engine/utils");
const url_1 = require("url");
/**
 * Creates a CodeEngine `File` object from a node `Stats` object.
 * @internal
 */
function createFile(relativePath, absolutePath, stats) {
    let info = createFileInfo(relativePath, absolutePath, stats);
    return utils_1.createFile(info);
}
exports.createFile = createFile;
/**
 * Creates a CodeEngine `ChangedFile` object from a node `Stats` object.
 * @internal
 */
function createChangedFile(relativePath, absolutePath, stats, change) {
    let info = createFileInfo(relativePath, absolutePath, stats);
    info.change = change;
    return utils_1.createChangedFile(info);
}
exports.createChangedFile = createChangedFile;
/**
 * Creates a CodeEngine `FileInfo` object from a node `Stats` object.
 * @internal
 */
function createFileInfo(relativePath, absolutePath, stats) {
    let info = {
        path: relativePath,
        source: url_1.pathToFileURL(absolutePath),
    };
    if (stats) {
        info.createdAt = stats.birthtime;
        info.modifiedAt = stats.mtime;
        info.metadata = createMetadata(stats);
    }
    return info;
}
/**
 * Copies all properties (except methods) of the `Stats` object.
 */
function createMetadata(stats) {
    let metadata = {};
    for (let [key, value] of Object.entries(stats)) {
        if (typeof value !== "function") {
            metadata[key] = value;
        }
    }
    return metadata;
}
//# sourceMappingURL=create-file.js.map